package com.ruoyi.ss.transactionBill.domain.vo;

import com.fasterxml.jackson.annotation.JsonView;
import com.ruoyi.common.core.domain.JsonViewProfile;
import com.ruoyi.common.pay.wx.domain.BatchTransferAble;
import com.ruoyi.common.pay.wx.domain.enums.TransferScene;
import com.ruoyi.ss.suit.domain.enums.SuitTimeUnit;
import com.ruoyi.ss.transactionBill.domain.TransactionBill;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.math.BigDecimal;

/**
 * @author 辉
 * 2024/3/4
 */
@ApiModel
@Data
public class TransactionBillVO extends TransactionBill implements BatchTransferAble {
    @ApiModelProperty("用户名称")
    @JsonView(JsonViewProfile.App.class)
    private String userName;

    @ApiModelProperty("商户（到账用户）名称")
    @JsonView(JsonViewProfile.App.class)
    private String mchName;

    @ApiModelProperty("支付渠道名称")
    @JsonView(JsonViewProfile.App.class)
    private String channelName;

    @ApiModelProperty("商户手机号")
    @JsonView(JsonViewProfile.AppMch.class)
    private String mchMobile;

    @ApiModelProperty("设备编号")
    @JsonView(JsonViewProfile.App.class)
    private String deviceNo;

    @ApiModelProperty("用户手机号")
    @JsonView(JsonViewProfile.App.class)
    private String userMobile;

    /**
     * 获取套餐时长（秒）
     */
    public long toSecondSuitTime() {
        SuitTimeUnit unit = SuitTimeUnit.getByValue(this.getSuitTimeUnit());
        if (unit == null) {
            unit = SuitTimeUnit.MINUTE;
        }
        long time = this.getSuitTime() == null ? 0 : this.getSuitTime();
        return time * unit.getConversion();
    }

    /**
     * 转账场景
     */
    @Override
    public TransferScene transferScene() {
        return TransferScene.WITHDRAW;
    }

    /**
     * 转账到账账号
     */
    @Override
    public String transferAccountNo() {
        return getAccountNo();
    }

    /**
     * 转账金额
     */
    @Override
    public BigDecimal transferAmount() {
        return getArrivalAmount();
    }

    /**
     * 转账外部订单号
     */
    @Override
    public String transferOutBatchNo() {
        return getBillNo();
    }

    /**
     * 转账备注
     */
    @Override
    public String transferBatchRemark() {
        return String.format("用户%s提现%f元", getUserName(), getArrivalAmount());
    }

    /**
     * 转账名称
     */
    @Override
    public String transferBatchName() {
        return "提现";
    }
}
